==> typegram-0.0.1-py3-none-any.whl: typegram/api/types/messageReplyHeader.py <==

#===========================================================
#            Copyright (C) 2023-present AyiinXd
#===========================================================
#||                                                       ||
#||              _         _ _      __  __   _            ||
#||             /   _   _(_|_)_ __  / /__| |           ||
#||            / _ | | | | | | '_     _  | |           ||
#||           / ___  |_| | | | | | |/   (_| |           ||
#||          /_/   ___, |_|_|_| |_/_/___,_|           ||
#||                  |___/                                ||
#||                                                       ||
#===========================================================
# Appreciating the work of others is not detrimental to you
#===========================================================
#

from io import BytesIO
from typing import Any, Union, List, Optional

from typegram.api import ayiin, functions
from typegram.api.object import Object
from typegram.api.utils import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector



class MessageReplyHeader(Object):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~typegram.api.ayiin.MessageReplyHeader`.

    Details:
        - Layer: ``181``
        - ID: ``AFBC09DB``

reply_to_scheduled (``bool``, *optional*):
                    N/A
                
        forum_topic (``bool``, *optional*):
                    N/A
                
        quote (``bool``, *optional*):
                    N/A
                
        reply_to_msg_id (``int`` ``32-bit``, *optional*):
                    N/A
                
        reply_to_peer_id (:obj:`Peer<typegram.api.ayiin.Peer>`, *optional*):
                    N/A
                
        reply_from (:obj:`MessageFwdHeader<typegram.api.ayiin.MessageFwdHeader>`, *optional*):
                    N/A
                
        reply_media (:obj:`MessageMedia<typegram.api.ayiin.MessageMedia>`, *optional*):
                    N/A
                
        reply_to_top_id (``int`` ``32-bit``, *optional*):
                    N/A
                
        quote_text (``str``, *optional*):
                    N/A
                
        quote_entities (List of :obj:`MessageEntity<typegram.api.ayiin.MessageEntity>`, *optional*):
                    N/A
                
        quote_offset (``int`` ``32-bit``, *optional*):
                    N/A
                
    Functions:
        This object can be returned by 19 functions.

        .. currentmodule:: typegram.api.functions

        .. autosummary::
            :nosignatures:

            .X
            .RpcDropAnswer
            .Bool
            .Authorization
            .PeerNotifySettings
            .User
            .Vector<SecureValue>
            .SecureValue
            .Updates
            .WallPaper
            .Document
            .Theme
            .Vector<WallPaper>
            .GlobalPrivacySettings
            .EmojiList
            .BusinessChatLink
            .ReactionsNotifySettings
            .Vector<User>
            .Vector<Bool>
            .Vector<int>
            .Vector<ReceivedNotifyMessage>
            .EncryptedChat
            .Vector<long>
            .MessageMedia
            .ExportedChatInvite
            .ChatInvite
            .Vector<StickerSetCovered>
            .EncryptedFile
            .ChatOnlines
            .EmojiKeywordsDifference
            .Vector<EmojiLanguage>
            .EmojiURL
            .UrlAuthResult
            .Vector<ReadParticipantDate>
            .AttachMenuBots
            .AttachMenuBotsBot
            .WebViewResult
            .SimpleWebViewResult
            .WebViewMessageSent
            .Vector<Document>
            .AppWebViewResult
            .OutboxReadDate
            .Vector<FactCheck>
            .Vector<FileHash>
            .ExportedMessageLink
            .DataJSON
            .Vector<BotCommand>
            .BotMenuButton
            .Vector<PremiumGiftCodeOption>
            .LangPackDifference
            .Vector<LangPackString>
            .Vector<LangPackLanguage>
            .LangPackLanguage
            .StatsGraph
            .ExportedChatlistInvite
            .Vector<Peer>
            .ExportedStoryLink
            .SmsJob
            .ResPQ
            .P_Q_inner_data
            .BindAuthKeyInner
            .Server_DH_Params
            .Server_DH_inner_data
            .Client_DH_Inner_Data
            .Set_client_DH_params_answer
    """

    __slots__: List[str] = ["reply_to_scheduled", "forum_topic", "quote", "reply_to_msg_id", "reply_to_peer_id", "reply_from", "reply_media", "reply_to_top_id", "quote_text", "quote_entities", "quote_offset"]

    ID = 0xafbc09db
    QUALNAME = "functions.types.MessageReplyHeader"

    def __init__(self, *, reply_to_scheduled: Optional[bool] = None, forum_topic: Optional[bool] = None, quote: Optional[bool] = None, reply_to_msg_id: Optional[int] = None, reply_to_peer_id: "ayiin.Peer" = None, reply_from: "ayiin.MessageFwdHeader" = None, reply_media: "ayiin.MessageMedia" = None, reply_to_top_id: Optional[int] = None, quote_text: Optional[str] = None, quote_entities: Optional[List["ayiin.MessageEntity"]] = None, quote_offset: Optional[int] = None) -> None:
        
                self.reply_to_scheduled = reply_to_scheduled  # true
        
                self.forum_topic = forum_topic  # true
        
                self.quote = quote  # true
        
                self.reply_to_msg_id = reply_to_msg_id  # int
        
                self.reply_to_peer_id = reply_to_peer_id  # Peer
        
                self.reply_from = reply_from  # MessageFwdHeader
        
                self.reply_media = reply_media  # MessageMedia
        
                self.reply_to_top_id = reply_to_top_id  # int
        
                self.quote_text = quote_text  # string
        
                self.quote_entities = quote_entities  # MessageEntity
        
                self.quote_offset = quote_offset  # int

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "MessageReplyHeader":
        
        flags = Int.read(b)
        
        reply_to_scheduled = True if flags & (1 << 2) else False
        forum_topic = True if flags & (1 << 3) else False
        quote = True if flags & (1 << 9) else False
        reply_to_msg_id = Int.read(b) if flags & (1 << 4) else None
        reply_to_peer_id = Object.read(b) if flags & (1 << 0) else None
        
        reply_from = Object.read(b) if flags & (1 << 5) else None
        
        reply_media = Object.read(b) if flags & (1 << 8) else None
        
        reply_to_top_id = Int.read(b) if flags & (1 << 1) else None
        quote_text = String.read(b) if flags & (1 << 6) else None
        quote_entities = Object.read(b) if flags & (1 << 7) else []
        
        quote_offset = Int.read(b) if flags & (1 << 10) else None
        return MessageReplyHeader(reply_to_scheduled=reply_to_scheduled, forum_topic=forum_topic, quote=quote, reply_to_msg_id=reply_to_msg_id, reply_to_peer_id=reply_to_peer_id, reply_from=reply_from, reply_media=reply_media, reply_to_top_id=reply_to_top_id, quote_text=quote_text, quote_entities=quote_entities, quote_offset=quote_offset)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        
        b.write(Int(flags))
        
        if self.reply_to_msg_id is not None:
            b.write(Int(self.reply_to_msg_id))
        
        if self.reply_to_peer_id is not None:
            b.write(self.reply_to_peer_id.write())
        
        if self.reply_from is not None:
            b.write(self.reply_from.write())
        
        if self.reply_media is not None:
            b.write(self.reply_media.write())
        
        if self.reply_to_top_id is not None:
            b.write(Int(self.reply_to_top_id))
        
        if self.quote_text is not None:
            b.write(String(self.quote_text))
        
        if self.quote_entities is not None:
            b.write(Vector(self.quote_entities))
        
        if self.quote_offset is not None:
            b.write(Int(self.quote_offset))
        
        return b.getvalue()

==> typegram-0.0.2-py3-none-any.whl: typegram/api/types/messageReplyHeader.py <==

#===========================================================
#            Copyright (C) 2023-present AyiinXd
#===========================================================
#||                                                       ||
#||              _         _ _      __  __   _            ||
#||             /   _   _(_|_)_ __  / /__| |           ||
#||            / _ | | | | | | '_     _  | |           ||
#||           / ___  |_| | | | | | |/   (_| |           ||
#||          /_/   ___, |_|_|_| |_/_/___,_|           ||
#||                  |___/                                ||
#||                                                       ||
#===========================================================
# Appreciating the work of others is not detrimental to you
#===========================================================
#

from io import BytesIO
from typing import Any, Union, List, Optional

from typegram import api
from typegram.api.object import Object
from typegram.api.utils import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector



class MessageReplyHeader(Object):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~typegram.api.ayiin.MessageReplyHeader`.

    Details:
        - Layer: ``181``
        - ID: ``AFBC09DB``

reply_to_scheduled (``bool``, *optional*):
                    N/A
                
        forum_topic (``bool``, *optional*):
                    N/A
                
        quote (``bool``, *optional*):
                    N/A
                
        reply_to_msg_id (``int`` ``32-bit``, *optional*):
                    N/A
                
        reply_to_peer_id (:obj:`Peer<typegram.api.ayiin.Peer>`, *optional*):
                    N/A
                
        reply_from (:obj:`MessageFwdHeader<typegram.api.ayiin.MessageFwdHeader>`, *optional*):
                    N/A
                
        reply_media (:obj:`MessageMedia<typegram.api.ayiin.MessageMedia>`, *optional*):
                    N/A
                
        reply_to_top_id (``int`` ``32-bit``, *optional*):
                    N/A
                
        quote_text (``str``, *optional*):
                    N/A
                
        quote_entities (List of :obj:`MessageEntity<typegram.api.ayiin.MessageEntity>`, *optional*):
                    N/A
                
        quote_offset (``int`` ``32-bit``, *optional*):
                    N/A
                
    """

    __slots__: List[str] = ["reply_to_scheduled", "forum_topic", "quote", "reply_to_msg_id", "reply_to_peer_id", "reply_from", "reply_media", "reply_to_top_id", "quote_text", "quote_entities", "quote_offset"]

    ID = 0xafbc09db
    QUALNAME = "types.messageReplyHeader"

    def __init__(self, *, reply_to_scheduled: Optional[bool] = None, forum_topic: Optional[bool] = None, quote: Optional[bool] = None, reply_to_msg_id: Optional[int] = None, reply_to_peer_id: "api.ayiin.Peer" = None, reply_from: "api.ayiin.MessageFwdHeader" = None, reply_media: "api.ayiin.MessageMedia" = None, reply_to_top_id: Optional[int] = None, quote_text: Optional[str] = None, quote_entities: Optional[List["api.ayiin.MessageEntity"]] = None, quote_offset: Optional[int] = None) -> None:
        
                self.reply_to_scheduled = reply_to_scheduled  # true
        
                self.forum_topic = forum_topic  # true
        
                self.quote = quote  # true
        
                self.reply_to_msg_id = reply_to_msg_id  # int
        
                self.reply_to_peer_id = reply_to_peer_id  # Peer
        
                self.reply_from = reply_from  # MessageFwdHeader
        
                self.reply_media = reply_media  # MessageMedia
        
                self.reply_to_top_id = reply_to_top_id  # int
        
                self.quote_text = quote_text  # string
        
                self.quote_entities = quote_entities  # MessageEntity
        
                self.quote_offset = quote_offset  # int

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "MessageReplyHeader":
        
        flags = Int.read(b)
        
        reply_to_scheduled = True if flags & (1 << 2) else False
        forum_topic = True if flags & (1 << 3) else False
        quote = True if flags & (1 << 9) else False
        reply_to_msg_id = Int.read(b) if flags & (1 << 4) else None
        reply_to_peer_id = Object.read(b) if flags & (1 << 0) else None
        
        reply_from = Object.read(b) if flags & (1 << 5) else None
        
        reply_media = Object.read(b) if flags & (1 << 8) else None
        
        reply_to_top_id = Int.read(b) if flags & (1 << 1) else None
        quote_text = String.read(b) if flags & (1 << 6) else None
        quote_entities = Object.read(b) if flags & (1 << 7) else []
        
        quote_offset = Int.read(b) if flags & (1 << 10) else None
        return MessageReplyHeader(reply_to_scheduled=reply_to_scheduled, forum_topic=forum_topic, quote=quote, reply_to_msg_id=reply_to_msg_id, reply_to_peer_id=reply_to_peer_id, reply_from=reply_from, reply_media=reply_media, reply_to_top_id=reply_to_top_id, quote_text=quote_text, quote_entities=quote_entities, quote_offset=quote_offset)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        
        b.write(Int(flags))
        
        if self.reply_to_msg_id is not None:
            b.write(Int(self.reply_to_msg_id))
        
        if self.reply_to_peer_id is not None:
            b.write(self.reply_to_peer_id.write())
        
        if self.reply_from is not None:
            b.write(self.reply_from.write())
        
        if self.reply_media is not None:
            b.write(self.reply_media.write())
        
        if self.reply_to_top_id is not None:
            b.write(Int(self.reply_to_top_id))
        
        if self.quote_text is not None:
            b.write(String(self.quote_text))
        
        if self.quote_entities is not None:
            b.write(Vector(self.quote_entities))
        
        if self.quote_offset is not None:
            b.write(Int(self.quote_offset))
        
        return b.getvalue()
